/**
 * Copyright (c) 2011-2012 EBM WebSourcing, 2012-2015 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see <http://www.gnu.org/licenses/>
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.component.framework.junit.impl.message;

import java.io.InputStream;

import javax.jbi.messaging.MessageExchange;
import javax.jbi.messaging.MessageExchange.Role;
import javax.jbi.messaging.MessagingException;
import javax.jbi.messaging.NormalizedMessage;
import javax.xml.transform.Source;
import javax.xml.transform.stream.StreamSource;

import org.ow2.petals.component.framework.api.message.Exchange;
import org.ow2.petals.component.framework.junit.ResponseMessage;
import org.ow2.petals.jbi.messaging.exchange.PetalsMessageExchange;

import com.ebmwebsourcing.easycommons.lang.UncheckedException;

/**
 * @author Marc Jambert - EBM WebSourcing
 */
public class WrappedResponseToConsumerMessage extends AbstractWrappedToComponentMessage implements ResponseMessage {

    public WrappedResponseToConsumerMessage(final MessageExchange messageExchange,
            final InputStream outMessageContentStream) {
        this(messageExchange);

        try {
            this.messageExchange.setRole(Role.PROVIDER);

            final NormalizedMessage outNm = this.messageExchange.createMessage();
            outNm.setContent(new StreamSource(outMessageContentStream));
            this.messageExchange.setMessage(outNm, Exchange.OUT_MESSAGE_NAME);

            this.messageExchange.setRole(Role.CONSUMER);
        } catch (final MessagingException e) {
            throw new UncheckedException("Impossible to create a message exchange", e);
        }
    }

    public WrappedResponseToConsumerMessage(final MessageExchange messageExchange) {
        super(messageExchange);
        this.messageExchange.setRole(Role.CONSUMER);
    }

    @Override
    public Source getPayload() {
        return getPayload(PetalsMessageExchange.OUT_MSG);
    }

    @Override
    public Source getFault() {
        return getPayload(PetalsMessageExchange.FAULT_MSG);
    }

    @Override
    public Exception getError() {
        return this.getMessageExchange().getError();
    }
}
